/*for full moon version*/

#include <avr/sleep.h>
#include <Adafruit_NeoPixel.h>
#include <avr/power.h>
#include "PinChangeInterrupt.h"

#define LDR 2     //PIR 1 interrupt pin -> for photoresistor detection in this version
#define PIR_2 5
#define PIR_3 7
#define PIN 6       // led strip in
#define CONVERTER 3 //converter enable pin
#define RELAY 4     //relay nais command pin
#define TEMPO 20000 //time to let the strip on
#define DEBUG false
#define VERBOSE false

Adafruit_NeoPixel strip = Adafruit_NeoPixel(22, PIN, NEO_GRB + NEO_KHZ800);
volatile byte pir_nb; //which pir has triggered ?

void setup() {
  Serial.begin(9600);
  pinMode(LDR, INPUT);
  pinMode(PIR_2, INPUT);
  pinMode(PIR_3, INPUT);
  pinMode(CONVERTER,OUTPUT);
  pinMode(RELAY,OUTPUT);

  if (DEBUG) Serial.println("started");
  
  strip.begin();
  strip.show();

  digitalWrite(CONVERTER,HIGH); //enable boost converter, in this version the booster converter is always ON

  //say hello
  if (VERBOSE) Serial.println("Connect led strip - Relay ON");
  digitalWrite(RELAY,HIGH); //connect led strip
  if (VERBOSE) Serial.println("Turn on boost converter");
  if (VERBOSE) Serial.println("Wipe to say hello!"); 
  for (int i=0;i<2;i++)
  {
    colorWipe(strip.Color(45,20,35),12);
    delay(500);
    colorWipe(strip.Color(0,0,0),12);
    delay(500);
  }
  if (VERBOSE) Serial.println("Strip OFF");
  strip_off();

  noInterrupts();
  //attachPCINT(digitalPinToPCINT(LDR),wakeUp_1,RISING);
  attachPCINT(digitalPinToPCINT(PIR_2),wakeUp_2,RISING);
  attachPCINT(digitalPinToPCINT(PIR_3),wakeUp_3,RISING);
}

void loop() {
  if (DEBUG) Serial.println("Loop");
  pir_nb=0; 
  Going_To_Sleep(); //set interrupt enable
 
  //the interrupt wakes up the uC at this point
  if (digitalRead(LDR)==HIGH)
  {
     if (pir_nb!=0) 
   {
      detachPCINT(digitalPinToPCINT(PIR_2)); //cli() does not work here
      detachPCINT(digitalPinToPCINT(PIR_3)); //because of strip library
      if (DEBUG) Serial.println("Strip ON");
      strip_on();
      delay(TEMPO);
      if (DEBUG) Serial.println("Strip OFF");
      strip_off();
      attachPCINT(digitalPinToPCINT(PIR_2),wakeUp_2,RISING);
      attachPCINT(digitalPinToPCINT(PIR_3),wakeUp_3,RISING);
    }
  }
  else if (DEBUG) Serial.println("Not dark enough to light the strip!");
}

void Going_To_Sleep()
{
  set_sleep_mode(SLEEP_MODE_PWR_DOWN);
  sleep_enable();
  interrupts();
  sleep_cpu();  
}

void wakeUp_1()
{
  pir_nb=1;
  if (DEBUG) 
  {
    blynk(1);
    Serial.println("Interrupt 1 Fired");
  }
}

void wakeUp_2()
{
  pir_nb=2;
  if (DEBUG) 
  {
    blynk(2);
    Serial.println("Interrupt 2 Fired");
  }
}

void wakeUp_3()
{
  pir_nb=3;
  if (DEBUG) 
  {
    blynk(3);
    Serial.println("Interrupt 3 Fired");
  }
 }

void blynk(int a)
{
  for (int i=0;i<a;i++)
  {
    digitalWrite(13,HIGH);
    for (long j=0;j<125000;j++) {__asm__("nop\n\t");} //equivalent to delay
    digitalWrite(13,LOW);
    for (long j=0;j<125000;j++) {__asm__("nop\n\t");};
  }
}
